@@ -138,6 +138,16 @@ test_that("invalid dates must be resolved when converting to a naive-time", {
   expect_snapshot_error(as_naive_time(year_day(2019, 366)))
 })
 
+# ------------------------------------------------------------------------------
+# format()
+
+test_that("default formats are correct", {
+  expect_snapshot(format(year_day(2019)))
+  expect_snapshot(format(year_day(2019, 1)))
+  expect_snapshot(format(year_day(2019, 1, 1)))
+  expect_snapshot(format(year_day(2019, 1, 1, 2, 3, 50, subsecond_precision = "microsecond")))
+})
+
 # ------------------------------------------------------------------------------
 # as.character()
 
