@@ -106,6 +106,16 @@ test_that("abbreviated ptype is correct", {
   expect_snapshot_output(vec_ptype_abbr(iso_year_week_day(2019, 53)))
 })
 
+# ------------------------------------------------------------------------------
+# format()
+
+test_that("default formats are correct", {
+  expect_snapshot(format(iso_year_week_day(2019)))
+  expect_snapshot(format(iso_year_week_day(2019, 1)))
+  expect_snapshot(format(iso_year_week_day(2019, 1, 1, 1)))
+  expect_snapshot(format(iso_year_week_day(2019, 1, 1, 1, 2, 3, 50, subsecond_precision = "microsecond")))
+})
+
 # ------------------------------------------------------------------------------
 # as.character()
 
