@@ -50,7 +50,7 @@ test_that("can convert naive-time -> POSIXct", {
 })
 
 test_that("can convert zoned-time -> POSIXct", {
-  x <- as_zoned_time(naive_time_parse("2019-01-01 23:02:03"), "America/New_York")
+  x <- as_zoned_time(naive_time_parse("2019-01-01T23:02:03"), "America/New_York")
   expect <- date_time_parse("2019-01-01 23:02:03", "America/New_York")
   expect_identical(as_date_time(x), expect)
 })
@@ -77,11 +77,11 @@ test_that("can resolve ambiguous midnight issues for Date -> POSIXct", {
 
   expect_identical(
     as_date_time(x, zone, ambiguous = "earliest"),
-    date_time_parse_complete("2021-10-29 00:00:00+03:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+03:00[Asia/Amman]")
   )
   expect_identical(
     as_date_time(x, zone, ambiguous = "latest"),
-    date_time_parse_complete("2021-10-29 00:00:00+02:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+02:00[Asia/Amman]")
   )
 })
 
@@ -89,7 +89,7 @@ test_that("can resolve ambiguous midnight issues for Date -> POSIXct", {
 # as.POSIXct()
 
 test_that("casting to POSIXct floors components more precise than seconds (#205)", {
-  x <- naive_time_parse("1969-01-01 01:01:01.678", precision = "millisecond")
+  x <- naive_time_parse("1969-01-01T01:01:01.678", precision = "millisecond")
 
   expect_identical(
     as.POSIXct(x, "America/New_York"),
@@ -270,6 +270,11 @@ test_that("can convert to a month factor", {
 # ------------------------------------------------------------------------------
 # date_format()
 
+test_that("default format is correct", {
+  x <- date_time_parse("2019-01-01 00:00:00", "America/New_York")
+  expect_snapshot(date_format(x))
+})
+
 test_that("can format date-times", {
   x <- as.POSIXct("2018-12-31 23:59:59", "America/New_York")
   format <- test_all_formats()
@@ -346,18 +351,18 @@ test_that("failure to parse throws a warning", {
 
 test_that("can parse into a POSIXct", {
   expect_identical(
-    date_time_parse_complete("2019-12-31 23:59:59-05:00[America/New_York]"),
+    date_time_parse_complete("2019-12-31T23:59:59-05:00[America/New_York]"),
     as.POSIXct("2019-12-31 23:59:59", tz = "America/New_York")
   )
 })
 
 test_that("ambiguity is resolved through the string", {
   expect_identical(
-    date_time_parse_complete("1970-10-25 01:30:00-04:00[America/New_York]"),
+    date_time_parse_complete("1970-10-25T01:30:00-04:00[America/New_York]"),
     add_seconds(date_time_parse("1970-10-25 00:30:00", "America/New_York"), 3600)
   )
   expect_identical(
-    date_time_parse_complete("1970-10-25 01:30:00-05:00[America/New_York]"),
+    date_time_parse_complete("1970-10-25T01:30:00-05:00[America/New_York]"),
     add_seconds(date_time_parse("1970-10-25 00:30:00", "America/New_York"), 7200)
   )
 })
@@ -393,6 +398,33 @@ test_that("abbrev - throws warning on failed parses", {
   expect_snapshot(date_time_parse_abbrev("foo", "America/New_York"))
 })
 
+# ------------------------------------------------------------------------------
+# date_time_parse_RFC_3339()
+
+test_that("can parse default RFC 3339 format", {
+  x <- "2019-01-01T00:00:01Z"
+  expect_identical(
+    date_time_parse_RFC_3339(x),
+    date_time_build(2019, 1, 1, 0, 0, 1, zone = "UTC")
+  )
+})
+
+test_that("`offset` is passed through", {
+  x <- "2019-01-01T00:00:01-03:30"
+  expect_identical(
+    date_time_parse_RFC_3339(x, offset = "%Ez"),
+    as_date_time(sys_time_parse_RFC_3339(x, offset = "%Ez"), zone = "UTC")
+  )
+})
+
+test_that("`separator` is passed through", {
+  x <- "2019-01-01 00:00:01Z"
+  expect_identical(
+    date_time_parse_RFC_3339(x, separator = " "),
+    as_date_time(sys_time_parse_RFC_3339(x, separator = " "), zone = "UTC")
+  )
+})
+
 # ------------------------------------------------------------------------------
 # date_shift()
 
@@ -468,11 +500,11 @@ test_that("can handle ambiguous times", {
 
   expect_identical(
     date_time_build(1970, 10, 25, 1, 30, zone = zone, ambiguous = "earliest"),
-    date_time_parse_complete("1970-10-25 01:30:00-04:00[America/New_York]")
+    date_time_parse_complete("1970-10-25T01:30:00-04:00[America/New_York]")
   )
   expect_identical(
     date_time_build(1970, 10, 25, 1, 30, zone = zone, ambiguous = "latest"),
-    date_time_parse_complete("1970-10-25 01:30:00-05:00[America/New_York]")
+    date_time_parse_complete("1970-10-25T01:30:00-05:00[America/New_York]")
   )
 })
 
@@ -522,11 +554,11 @@ test_that("can resolve ambiguous start issues", {
 
   expect_identical(
     date_start(x, "day", ambiguous = "earliest"),
-    date_time_parse_complete("2021-10-29 00:00:00+03:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+03:00[Asia/Amman]")
   )
   expect_identical(
     date_start(x, "day", ambiguous = "latest"),
-    date_time_parse_complete("2021-10-29 00:00:00+02:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+02:00[Asia/Amman]")
   )
 })
 
@@ -538,14 +570,14 @@ test_that("can automatically resolve ambiguous issues", {
   x <- date_time_build(2021, 10, 29, 0, 20, zone = zone, ambiguous = "earliest")
   expect_identical(
     date_start(x, "day"),
-    date_time_parse_complete("2021-10-29 00:00:00+03:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+03:00[Asia/Amman]")
   )
 
   # Starts and ends the manipulation in the "latest" hour
   x <- date_time_build(2021, 10, 29, 0, 20, zone = zone, ambiguous = "latest")
   expect_identical(
     date_start(x, "day"),
-    date_time_parse_complete("2021-10-29 00:00:00+02:00[Asia/Amman]")
+    date_time_parse_complete("2021-10-29T00:00:00+02:00[Asia/Amman]")
   )
 })
 
