@@ -108,6 +108,16 @@ test_that("abbreviated ptype is correct", {
   expect_snapshot_output(vec_ptype_abbr(year_quarter_day(2019, 1, 92)))
 })
 
+# ------------------------------------------------------------------------------
+# format()
+
+test_that("default formats are correct", {
+  expect_snapshot(format(year_quarter_day(2019)))
+  expect_snapshot(format(year_quarter_day(2019, 1)))
+  expect_snapshot(format(year_quarter_day(2019, 1, 1, 1)))
+  expect_snapshot(format(year_quarter_day(2019, 1, 1, 1, 2, 3, 50, subsecond_precision = "microsecond")))
+})
+
 # ------------------------------------------------------------------------------
 # as.character()
 
